@@ -1,6 +1,6 @@
-import logging
-
-l = logging.getLogger("archinfo.arch_x86")
+from .arch import Arch, register_arch, Endness, Register
+from .tls import TLSArchInfo
+from .archerror import ArchError
 
 try:
     import capstone as _capstone
@@ -22,10 +22,6 @@ try:
 except ImportError:
     _pyvex = None
 
-from .arch import Arch, register_arch, Endness, Register
-from .tls import TLSArchInfo
-from .archerror import ArchError
-
 
 _NATIVE_FUNCTION_PROLOGS = [
     rb"\x8b\xff\x55\x8b\xec",  # mov edi, edi; push ebp; mov ebp, esp
